@@ -32,19 +32,13 @@
 #include <gconf/gconf-client.h>
 #include <libgnomeui/gnome-authentication-manager.h>
 #include <libgnomeui/gnome-help.h>
-#include <libgnomeprint/gnome-print.h>
-#include <libgnomeprint/gnome-print-job.h>
-#include <libgnomeprint/gnome-print-pango.h>
-#include <libgnomeprintui/gnome-print-dialog.h>
-#include <libgnomeprintui/gnome-print-job-preview.h>
 
 #include "gdict-applet.h"
 #include "gdict-about.h"
 #include "gdict-pref-dialog.h"
 #include "gdict-print.h"
 #include "gdict-common.h"
-
-#include "gtkalignedwindow.h"
+#include "gdict-aligned-window.h"
 
 #define GDICT_APPLET_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), GDICT_TYPE_APPLET, GdictAppletClass))
 #define GDICT_APPLET_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS ((obj), GDICT_TYPE_APPLET, GdictAppletClass))
@@ -61,8 +55,6 @@ struct _GdictAppletPrivate
   guint size;
   GtkOrientation orient;
   
-  GtkTooltips *tooltips;
-  
   GConfClient *gconf_client;
   guint notify_id;
   guint font_notify_id;
@@ -101,8 +93,8 @@ struct _GdictAppletPrivate
 
 #define WINDOW_MIN_WIDTH 	300
 #define WINDOW_MIN_HEIGHT 	200
-#define WINDOW_NUM_COLUMNS 	56
-#define WINDOW_NUM_ROWS  	23
+#define WINDOW_NUM_COLUMNS 	47
+#define WINDOW_NUM_ROWS  	20
 
 G_DEFINE_TYPE (GdictApplet, gdict_applet, PANEL_TYPE_APPLET);
 
@@ -162,18 +154,17 @@ set_window_default_size (GdictApplet *applet)
   width = MAX (width, req.width);
   height = MAX (height, req.height);
 
-  /* ... but make it no larger than the monitor */
+  /* ... but make it no larger than half the monitor size */
   screen = gtk_widget_get_screen (widget);
   monitor_num = gdk_screen_get_monitor_at_window (screen, widget->window);
 
   gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
 
-  width = MIN (width, monitor.width * 3 / 4);
-  height = MIN (height, monitor.height * 3 / 4);
+  width = MIN (width, monitor.width / 2);
+  height = MIN (height, monitor.height / 2);
 
   /* Set size */
   gtk_widget_set_size_request (priv->frame, width, height);
-
 }
 
 static void
@@ -200,7 +191,6 @@ print_cb (GtkWidget   *widget,
     return;
   
   gdict_show_print_dialog (GTK_WINDOW (priv->window),
-  			   _("Print"),
   			   GDICT_DEFBOX (priv->defbox));
 }
 
@@ -291,11 +281,19 @@ window_key_press_event_cb (GtkWidget   *widget,
 			   GdkEventKey *event,
 			   gpointer     user_data)
 {
+  GdictApplet *applet = GDICT_APPLET (user_data);
+  
   if (event->keyval == GDK_Escape)
     {
-      GdictApplet *applet = GDICT_APPLET (user_data);
-
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (applet->priv->toggle), FALSE);
+      gtk_toggle_button_toggled (GTK_TOGGLE_BUTTON (applet->priv->toggle));
+
+      return TRUE;
+    }
+  else if ((event->keyval == GDK_l) &&
+	   (event->state & GDK_CONTROL_MASK))
+    {
+      gtk_widget_grab_focus (applet->priv->entry);
 
       return TRUE;
     }
@@ -303,6 +301,13 @@ window_key_press_event_cb (GtkWidget   *widget,
   return FALSE;
 }
 
+static void
+window_show_cb (GtkWidget   *window,
+		GdictApplet *applet)
+{
+  set_window_default_size (applet);
+}
+
 static void
 gdict_applet_build_window (GdictApplet *applet)
 {
@@ -320,10 +325,13 @@ gdict_applet_build_window (GdictApplet *applet)
       return;
     }
   
-  window = gtk_aligned_window_new (priv->toggle);
+  window = gdict_aligned_window_new (priv->toggle);
   g_signal_connect (window, "key-press-event",
 		    G_CALLBACK (window_key_press_event_cb),
 		    applet);
+  g_signal_connect (window, "show",
+  		    G_CALLBACK (window_show_cb),
+		    applet);
 
   frame = gtk_frame_new (NULL);
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
@@ -342,6 +350,8 @@ gdict_applet_build_window (GdictApplet *applet)
   
   gtk_box_pack_start (GTK_BOX (vbox), priv->defbox, TRUE, TRUE, 0);
   gtk_widget_show (priv->defbox);
+  GTK_WIDGET_SET_FLAGS (priv->defbox, GTK_CAN_FOCUS);
+  GTK_WIDGET_SET_FLAGS (priv->defbox, GTK_CAN_DEFAULT);
   
   bbox = gtk_hbutton_box_new ();
   gtk_button_box_set_layout (GTK_BUTTON_BOX (bbox), GTK_BUTTONBOX_END);
@@ -350,11 +360,7 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_widget_show (bbox);
   
   button = gtk_button_new_from_stock (GTK_STOCK_CLEAR);
-
-  gtk_tooltips_set_tip (priv->tooltips,
-		  	button,
-		  	_("Clear the definitions found"),
-			NULL);
+  gtk_widget_set_tooltip_text (button, _("Clear the definitions found"));
   set_atk_name_description (button,
 		  	    _("Clear definition"),
 			    _("Clear the text of the definition"));
@@ -364,11 +370,7 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_widget_show (button);
 
   button = gtk_button_new_from_stock (GTK_STOCK_PRINT);
-
-  gtk_tooltips_set_tip (priv->tooltips,
-		  	button,
-			_("Print the definitions found"),
-			NULL);
+  gtk_widget_set_tooltip_text (button, _("Print the definitions found"));
   set_atk_name_description (button,
 		  	    _("Print definition"),
 			    _("Print the text of the definition"));
@@ -378,11 +380,7 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_widget_show (button);
 
   button = gtk_button_new_from_stock (GTK_STOCK_SAVE);
-  
-  gtk_tooltips_set_tip (priv->tooltips,
-		  	button,
-			_("Save the definitions found"),
-			NULL);
+  gtk_widget_set_tooltip_text (button, _("Save the definitions found"));
   set_atk_name_description (button,
 		  	    _("Save definition"),
 			    _("Save the text of the definition to a file"));
@@ -391,32 +389,12 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_box_pack_start (GTK_BOX (bbox), button, FALSE, FALSE, 0);
   gtk_widget_show (button);
   
-  set_window_default_size (applet);
+  gtk_window_set_default (GTK_WINDOW (window), priv->defbox);
   
   priv->window = window;
   priv->is_window_showing = FALSE;
 }
 
-static void
-gdict_applet_toggle_window (GdictApplet *applet)
-{
-  GdictAppletPrivate *priv = applet->priv;
-  
-  if (!priv->window)
-    gdict_applet_build_window (applet);
-      
-  if (!priv->is_window_showing)
-    {
-      gtk_widget_show (priv->window);
-      priv->is_window_showing = TRUE;
-    }
-  else
-    {
-      gtk_widget_hide (priv->window);
-      priv->is_window_showing = FALSE;
-    }
-}
-
 static gboolean
 gdict_applet_icon_toggled_cb (GtkWidget   *widget,
 			      GdictApplet *applet)
@@ -428,12 +406,21 @@ gdict_applet_icon_toggled_cb (GtkWidget   *widget,
   
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
     {
-      gtk_widget_show (priv->window);
+      gtk_window_set_screen (GTK_WINDOW (priv->window),
+	                     gtk_widget_get_screen (GTK_WIDGET (applet)));
+      gtk_window_present (GTK_WINDOW (priv->window));
+      gtk_widget_grab_focus (priv->defbox);
+      
       priv->is_window_showing = TRUE;
     }
   else
     {
+      /* force hiding the find pane */
+      gdict_defbox_set_show_find (GDICT_DEFBOX (priv->defbox), FALSE);
+
+      gtk_widget_grab_focus (priv->entry);
       gtk_widget_hide (priv->window);
+      
       priv->is_window_showing = FALSE;
     }
 }
@@ -458,6 +445,32 @@ gdict_applet_entry_activate_cb (GtkWidget   *widget,
   gdict_defbox_lookup (GDICT_DEFBOX (priv->defbox), priv->word);
 }
 
+static gboolean
+gdict_applet_entry_key_press_cb (GtkWidget   *widget,
+				 GdkEventKey *event,
+				 gpointer     user_data)
+{
+  GdictAppletPrivate *priv = GDICT_APPLET (user_data)->priv;
+  
+  if (event->keyval == GDK_Escape)
+    {
+      if (priv->is_window_showing)
+	{
+          gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->toggle), FALSE);
+	  gtk_toggle_button_toggled (GTK_TOGGLE_BUTTON (priv->toggle));
+	  
+	  return TRUE;
+	}
+    }
+  else if (event->keyval == GDK_Tab)
+    {
+      if (priv->is_window_showing)
+	gtk_widget_grab_focus (priv->defbox);
+    }
+
+  return FALSE;
+}
+
 static gboolean
 gdict_applet_icon_button_press_event_cb (GtkWidget      *widget,
 					 GdkEventButton *event,
@@ -469,7 +482,7 @@ gdict_applet_icon_button_press_event_cb (GtkWidget      *widget,
    * user is toggling the button
    */
   if (event->button != 1)
-    g_signal_stop_emission_by_name(priv->toggle, "button-press-event");
+    g_signal_stop_emission_by_name (priv->toggle, "button-press-event");
 
   return FALSE;
 }
@@ -517,14 +530,10 @@ gdict_applet_draw (GdictApplet *applet)
 
   /* toggle button */
   priv->toggle = gtk_toggle_button_new ();
-  
+  gtk_widget_set_tooltip_text (priv->toggle, _("Click to view the dictionary window"));
   set_atk_name_description (priv->toggle,
 			    _("Toggle dictionary window"),
 		  	    _("Show or hide the definition window"));
-  gtk_tooltips_set_tip (priv->tooltips,
-		  	priv->toggle,
-		  	_("Click to view the dictionary window"),
-			NULL);
   
   gtk_button_set_relief (GTK_BUTTON (priv->toggle),
 		  	 GTK_RELIEF_NONE);
@@ -576,14 +585,10 @@ gdict_applet_draw (GdictApplet *applet)
 
   /* entry */
   priv->entry = gtk_entry_new ();
-  
+  gtk_widget_set_tooltip_text (priv->entry, _("Type the word you want to look up"));
   set_atk_name_description (priv->entry,
 		  	    _("Dictionary entry"),
 			    _("Look up words in dictionaries"));
-  gtk_tooltips_set_tip (priv->tooltips,
-		  	priv->entry,
-			_("Type the word you want to look up"),
-			NULL);
   
   gtk_entry_set_editable (GTK_ENTRY (priv->entry), TRUE);
   gtk_entry_set_width_chars (GTK_ENTRY (priv->entry), 12);
@@ -593,6 +598,9 @@ gdict_applet_draw (GdictApplet *applet)
   g_signal_connect (priv->entry, "button-press-event",
 		    G_CALLBACK (gdict_applet_entry_button_press_event_cb),
 		    applet);
+  g_signal_connect (priv->entry, "key-press-event",
+		    G_CALLBACK (gdict_applet_entry_key_press_cb),
+		    applet);
   gtk_box_pack_end (GTK_BOX (box), priv->entry, FALSE, FALSE, 0);
   gtk_widget_show (priv->entry);
 
@@ -604,8 +612,10 @@ gdict_applet_draw (GdictApplet *applet)
     }
   
   priv->box = box;
-  
+
+#if 0
   gtk_widget_grab_focus (priv->entry);
+#endif
   
   gtk_widget_show_all (GTK_WIDGET (applet));
 
@@ -633,7 +643,9 @@ gdict_applet_lookup_start_cb (GdictContext *context,
     {
       gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->toggle), TRUE);
       
-      gtk_widget_show (priv->window);
+      gtk_window_present (GTK_WINDOW (priv->window));
+      gtk_widget_grab_focus (priv->defbox);
+
       priv->is_window_showing = TRUE;
     }
 
@@ -645,6 +657,8 @@ gdict_applet_lookup_end_cb (GdictContext *context,
 			    GdictApplet  *applet)
 {
   gdict_applet_set_menu_items_sensitive (applet, TRUE);
+
+  gtk_window_present (GTK_WINDOW (applet->priv->window));
 }
 
 static void
@@ -652,12 +666,6 @@ gdict_applet_error_cb (GdictContext *context,
 		       const GError *error,
 		       GdictApplet  *applet)
 {
-  GdictAppletPrivate *priv = applet->priv;
-
-  /* force window hide */
-  gtk_widget_hide (priv->window);
-  priv->is_window_showing = FALSE;
-  
   /* disable menu items */
   gdict_applet_set_menu_items_sensitive (applet, FALSE);
 }
@@ -712,7 +720,7 @@ gdict_applet_cmd_preferences (BonoboUIComponent *component,
 			      GdictApplet       *applet,
 			      const gchar       *cname)
 {
-  gdict_show_pref_dialog (NULL,
+  gdict_show_pref_dialog (GTK_WIDGET (applet),
   			  _("Dictionary Preferences"),
   			  applet->priv->loader);
 }
@@ -722,7 +730,7 @@ gdict_applet_cmd_about (BonoboUIComponent *component,
 			GdictApplet       *applet,
 			const gchar       *cname)
 {
-  gdict_show_about_dialog (NULL);
+  gdict_show_about_dialog (GTK_WIDGET (applet));
 }
 
 static void
@@ -837,8 +845,9 @@ gdict_applet_style_set (GtkWidget *widget,
   if (GTK_WIDGET_CLASS (gdict_applet_parent_class)->style_set)
     GTK_WIDGET_CLASS (gdict_applet_parent_class)->style_set (widget,
 		    					     old_style);
-
+#if 0
   set_window_default_size (GDICT_APPLET (widget));
+#endif
 }
 
 static void
@@ -847,21 +856,17 @@ gdict_applet_set_database (GdictApplet *applet,
 {
   GdictAppletPrivate *priv = applet->priv;
   
-  if (priv->database)
-    g_free (priv->database);
-
-  if (!database)
-    database = gconf_client_get_string (priv->gconf_client,
-		    			GDICT_GCONF_DATABASE_KEY,
-					NULL);
-  
-  if (!database)
-    database = GDICT_DEFAULT_DATABASE;
-
-  priv->database = g_strdup (database);
+  g_free (priv->database);
 
+  if (database)
+    priv->database = g_strdup (database);
+  else
+    priv->database = gdict_gconf_get_string_with_default (priv->gconf_client,
+							  GDICT_GCONF_DATABASE_KEY,
+							  GDICT_DEFAULT_DATABASE);
   if (priv->defbox)
-    gdict_defbox_set_database (GDICT_DEFBOX (priv->defbox), database);
+    gdict_defbox_set_database (GDICT_DEFBOX (priv->defbox),
+			       priv->database);
 }
 
 static void
@@ -870,18 +875,14 @@ gdict_applet_set_strategy (GdictApplet *applet,
 {
   GdictAppletPrivate *priv = applet->priv;
   
-  if (priv->strategy)
-    g_free (priv->strategy);
+  g_free (priv->strategy);
 
-  if (!strategy)
-    strategy = gconf_client_get_string (priv->gconf_client,
-		    			GDICT_GCONF_STRATEGY_KEY,
-					NULL);
-
-  if (!strategy)
-    strategy = GDICT_DEFAULT_STRATEGY;
-
-  priv->strategy = g_strdup (strategy);
+  if (strategy)
+    priv->strategy = g_strdup (strategy);
+  else
+    priv->strategy = gdict_gconf_get_string_with_default (priv->gconf_client,
+							  GDICT_GCONF_STRATEGY_KEY,
+							  GDICT_DEFAULT_STRATEGY);
 }
 
 static GdictContext *
@@ -943,19 +944,15 @@ gdict_applet_set_print_font (GdictApplet *applet,
 			     const gchar *print_font)
 {
   GdictAppletPrivate *priv = applet->priv;
-  
-  if (!print_font)
-    print_font = gconf_client_get_string (priv->gconf_client,
-    					  GDICT_GCONF_PRINT_FONT_KEY,
-    					  NULL);
-  
-  if (!print_font)
-    print_font = GDICT_DEFAULT_PRINT_FONT;
-  
-  if (priv->print_font)
-    g_free (priv->print_font);
-  
-  priv->print_font = g_strdup (print_font);
+
+  g_free (priv->print_font);
+
+  if (print_font)
+    priv->print_font = g_strdup (print_font);
+  else
+    priv->print_font = gdict_gconf_get_string_with_default (priv->gconf_client,
+							    GDICT_GCONF_PRINT_FONT_KEY,
+							    GDICT_DEFAULT_PRINT_FONT);
 }
 
 static void
@@ -963,25 +960,19 @@ gdict_applet_set_defbox_font (GdictApplet *applet,
 			      const gchar *defbox_font)
 {
   GdictAppletPrivate *priv = applet->priv;
-  
-  if (!defbox_font)
-    defbox_font = gconf_client_get_string (priv->gconf_client,
-		    			   DOCUMENT_FONT_KEY,
-					   NULL);
 
-  if (!defbox_font)
-    defbox_font = GDICT_DEFAULT_DEFBOX_FONT;
+  g_free (priv->defbox_font);
 
-  if (priv->defbox_font)
-    g_free (priv->defbox_font);
+  if (defbox_font)
+    priv->defbox_font = g_strdup (defbox_font);
+  else
+    priv->defbox_font = gdict_gconf_get_string_with_default (priv->gconf_client,
+							     DOCUMENT_FONT_KEY,
+							     GDICT_DEFAULT_DEFBOX_FONT);
 
-  priv->defbox_font = g_strdup (defbox_font);
-
-  if (!priv->defbox)
-    return;
-
-  gdict_defbox_set_font_name (GDICT_DEFBOX (priv->defbox),
-			      priv->defbox_font);
+  if (priv->defbox)
+    gdict_defbox_set_font_name (GDICT_DEFBOX (priv->defbox),
+				priv->defbox_font);
 }
 
 static void
@@ -1042,23 +1033,17 @@ gdict_applet_set_source_name (GdictApplet *applet,
 {
   GdictAppletPrivate *priv = applet->priv;
   GdictContext *context;
-  
-  /* some sanity checks first */
-  if (!source_name)
-    source_name = gconf_client_get_string (priv->gconf_client,
-      					   GDICT_GCONF_SOURCE_KEY,
-      					   NULL);
-  
-  if (!source_name)
-    source_name = GDICT_DEFAULT_SOURCE_NAME;
-  
-  if (priv->source_name)
-    g_free (priv->source_name);
-  
-  priv->source_name = g_strdup (source_name);
+
+  g_free (priv->source_name);
+
+  if (source_name)
+    priv->source_name = g_strdup (source_name);
+  else
+    priv->source_name = gdict_gconf_get_string_with_default (priv->gconf_client,
+							     GDICT_GCONF_SOURCE_KEY,
+							     GDICT_DEFAULT_SOURCE_NAME);
   
   context = get_context_from_loader (applet);
-  
   gdict_applet_set_context (applet, context);
 }
 
@@ -1141,9 +1126,6 @@ gdict_applet_finalize (GObject *object)
   if (priv->loader)
     g_object_unref (priv->loader);
   
-  if (priv->tooltips)
-    g_object_unref (priv->tooltips);
-
   if (priv->icon)
     g_object_unref (priv->icon);
   
@@ -1183,19 +1165,15 @@ gdict_applet_init (GdictApplet *applet)
   priv = GDICT_APPLET_GET_PRIVATE (applet);
   applet->priv = priv;
       
-  data_dir = g_build_filename (g_get_home_dir (),
-  			       ".gnome2",
-  			       "gnome-dictionary",
-  			       NULL);
   if (!priv->loader)
     priv->loader = gdict_source_loader_new ();
 
   /* add our data dir inside $HOME to the loader's search paths */
+  data_dir = gdict_get_data_dir ();
   gdict_source_loader_add_search_path (priv->loader, data_dir);
-
   g_free (data_dir);
   
-  gtk_window_set_default_icon_name ("gnome-dictionary");
+  gtk_window_set_default_icon_name ("accessories-dictionary");
   
   panel_applet_set_flags (PANEL_APPLET (applet),
 			  PANEL_APPLET_EXPAND_MINOR);
@@ -1272,15 +1250,11 @@ gdict_applet_init (GdictApplet *applet)
 #endif /* !GDICT_APPLET_STAND_ALONE */
 
   priv->icon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
-		  			 "gnome-dictionary",
+		  			 "accessories-dictionary",
 					 48,
 					 0,
 					 NULL);
   
-  priv->tooltips = gtk_tooltips_new ();
-  g_object_ref (priv->tooltips);
-  gtk_object_sink (GTK_OBJECT (priv->tooltips));
-
   /* force first draw */
   gdict_applet_draw (applet);
 
